@@ -1,13 +1,7 @@
-#include <string.h>
+#include <string.h> /* memcmp */
 
-#define USING_R 1
-#include "S.h" 
-
-#ifdef USING_R
-# include <R.h>
-# include <Rinternals.h>
-# define S_EVALUATOR
-#endif
+#include <R.h>
+#include <Rinternals.h>
 
 #include "sp.h"
 
@@ -36,7 +30,6 @@ SEXP sp_zerodist(SEXP pp, SEXP pncol, SEXP zero, SEXP lonlat, SEXP mcmp) {
 	double **x, zerodist2;
 	SEXP ret = NULL;
 
-	S_EVALUATOR
 	ncol = INTEGER_POINTER(pncol)[0];
 	ll = INTEGER_POINTER(lonlat)[0];
 	cmp = INTEGER_POINTER(mcmp)[0];
@@ -46,8 +39,8 @@ SEXP sp_zerodist(SEXP pp, SEXP pncol, SEXP zero, SEXP lonlat, SEXP mcmp) {
 	zerodist2 = NUMERIC_POINTER(zero)[0] * NUMERIC_POINTER(zero)[0];
 	x = (double **) malloc((size_t) nrow * sizeof(double *));
 	if (x == NULL)
-		error("could not allocate vector of %u bytes in zerodist",
-			nrow * sizeof(double *));
+		error("could not allocate vector of %lu bytes in zerodist",
+			(long unsigned int) (nrow * sizeof(double *)));
 	for (i = 0; i < nrow; i++)
 		x[i] = &(NUMERIC_POINTER(pp)[i*ncol]);
 
@@ -80,7 +73,6 @@ SEXP sp_duplicates(SEXP pp, SEXP pncol, SEXP zero, SEXP lonlat, SEXP mcmp) {
 	double **x, zerodist2;
 	SEXP ret = NULL;
 
-	S_EVALUATOR
 	ncol = INTEGER_POINTER(pncol)[0];
 	ll = INTEGER_POINTER(lonlat)[0];
 	cmp = INTEGER_POINTER(mcmp)[0];
@@ -90,8 +82,8 @@ SEXP sp_duplicates(SEXP pp, SEXP pncol, SEXP zero, SEXP lonlat, SEXP mcmp) {
 	zerodist2 = NUMERIC_POINTER(zero)[0] * NUMERIC_POINTER(zero)[0];
 	x = (double **) malloc((size_t) nrow * sizeof(double *));
 	if (x == NULL)
-		error("could not allocate vector of %u bytes in zerodist",
-			nrow * sizeof(double *));
+		error("could not allocate vector of %lu bytes in zerodist",
+			(long unsigned int) (nrow * sizeof(double *)));
 	for (i = 0; i < nrow; i++)
 		x[i] = &(NUMERIC_POINTER(pp)[i*ncol]);
 
